Enum renderling_ui::LineJoin

source ยท
pub enum LineJoin {
    Miter,
    MiterClip,
    Round,
    Bevel,
}
Line join as defined by the SVG specification.

See: https://svgwg.org/specs/strokes/#StrokeLinejoinProperty

Variants



Miter

A sharp corner is to be used to join path segments.



MiterClip

Same as a miter join, but if the miter limit is exceeded, the miter is clipped at a miter length equal to the miter limit value multiplied by the stroke width.



Round

A round corner is to be used to join path segments.



Bevel

A beveled corner is to be used to join path segments. The bevel shape is a triangle that fills the area between the two stroked segments.