Struct renderling_ui::GlyphCache

source ·
pub struct GlyphCache { /* private fields */ }
A cache of glyphs.

Implementations

source

impl GlyphCache

source

pub fn get_updated( &mut self ) -> (Option<Vec<Vertex>>, Option<ImageBuffer<Luma<u8>, Vec<u8>>>)

Process any brushes, updating textures, etc.

Returns a new mesh if the mesh needs to be updated. Returns a new texture if the texture needs to be updated.

The texture and mesh are meant to be used to build or update a Renderlet to display.

Methods from Deref<Target = GlyphBrush<Vec<Vertex>>>

source

pub fn add_font<I>(&mut self, font_data: I) -> FontId
where I: Into<F>,

Adds an additional font to the one(s) initially added on build.

Returns a new FontId to reference this font.

source

pub fn queue_custom_layout<'a, S, G>(&mut self, section: S, custom_layout: &G)
where G: GlyphPositioner, X: 'a, S: Into<Cow<'a, Section<'a, X>>>,

Queues a section/layout to be processed by the next call of process_queued. Can be called multiple times to queue multiple sections for drawing.

Used to provide custom GlyphPositioner logic, if using built-in Layout simply use queue

Benefits from caching, see caching behaviour.

source

pub fn queue<'a, S>(&mut self, section: S)
where X: 'a, S: Into<Cow<'a, Section<'a, X>>>,

Queues a section/layout to be processed by the next call of process_queued. Can be called multiple times to queue multiple sections for drawing.

Benefits from caching, see caching behaviour.

glyph_brush.queue(Section::default().add_text(Text::new("Hello glyph_brush")));
source

pub fn queue_pre_positioned( &mut self, glyphs: Vec<SectionGlyph>, extra: Vec<X>, bounds: Rect )

Queues pre-positioned glyphs to be processed by the next call of process_queued. Can be called multiple times.

source

pub fn resize_texture(&mut self, new_width: u32, new_height: u32)

Rebuilds the logical texture cache with new dimensions. Should be avoided if possible.

Example
glyph_brush.resize_texture(512, 512);
source

pub fn texture_dimensions(&self) -> (u32, u32)

Returns the logical texture cache pixel dimensions (width, height).

source

pub fn keep_cached_custom_layout<'a, S, G>( &mut self, section: S, custom_layout: &G )
where S: Into<Cow<'a, Section<'a, X>>>, G: GlyphPositioner, X: 'a,

Retains the section in the cache as if it had been used in the last draw-frame.

Should not generally be necessary, see caching behaviour.

source

pub fn keep_cached<'a, S>(&mut self, section: S)
where S: Into<Cow<'a, Section<'a, X>>>, X: 'a,

Retains the section in the cache as if it had been used in the last draw-frame.

Should not generally be necessary, see caching behaviour.

source

pub fn process_queued<Up, VF>( &mut self, update_texture: Up, to_vertex: VF ) -> Result<BrushAction<V>, BrushError>
where Up: FnMut(Rectangle<u32>, &[u8]), VF: Fn(GlyphVertex<'_, X>) -> V + Copy,

Processes all queued sections, calling texture update logic when necessary & returning a BrushAction. See queue.

Two closures are required:

  • update_texture is called when new glyph texture data has been drawn for update in the actual texture. The arguments are the rect position of the data in the texture & the byte data itself which is a single u8 alpha value per pixel.
  • to_vertex maps a single glyph’s GlyphVertex data into a generic vertex type. The mapped vertices are returned in an Ok(BrushAction::Draw(vertices)) result. It’s recommended to use a single vertex per glyph quad for best performance.

Trims the cache, see caching behaviour.

glyph_brush.process_queued(
    |rect, tex_data| update_texture(rect, tex_data),
    |vertex_data| into_vertex(vertex_data),
)?
source

pub fn is_draw_cached(&self, font_id: FontId, glyph: &Glyph) -> bool

Returns true if this glyph is currently present in the draw cache texture.

So false means either this glyph is invisible, like ' ', or hasn’t been queued & processed yet.

source

pub fn to_builder(&self) -> GlyphBrushBuilder<F, H>

Return a GlyphBrushBuilder prefilled with the properties of this GlyphBrush.

Example
let glyph_brush: GlyphBrush<Vertex> = GlyphBrushBuilder::using_font(sans)
    .initial_cache_size((128, 128))
    .build();

let new_brush: GlyphBrush<Vertex> = glyph_brush.to_builder().build();
assert_eq!(new_brush.texture_dimensions(), (128, 128));